==> beast-0.6.1.tar.gz: beast-0.6.1/bse/bsewaveosc.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsewaveosc.proc"

#include <bse/bseplugin.h>
#include <bse/bsewaveosc.h>
#include <bse/bseprocedure.h>
#include <bse/bseeditablesample.h>

#line 25 "bsewaveosc.proc"


/* --- request-pcm-position --- */
static void
request_pcm_position_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 27 "bsewaveosc.proc"
 {
#line 29 "bsewaveosc.proc"
  *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
#line 31 "bsewaveosc.proc"
}  }
static BseErrorType
#line 31 "bsewaveosc.proc"
request_pcm_position_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 34 "bsewaveosc.proc"
{
#line 35 "bsewaveosc.proc"
  
  BseWaveOsc *self = bse_value_get_object (in_values++);
  
#line 38 "bsewaveosc.proc"
  
  if (!BSE_IS_WAVE_OSC (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  bse_wave_osc_request_pcm_position (self, -1);
  
  return BSE_ERROR_NONE;
}

/* --- pcm-seek-perc --- */
static void
pcm_seek_perc_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 47 "bsewaveosc.proc"
 {
#line 49 "bsewaveosc.proc"
  *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
  *(in_pspecs++) = sfi_pspec_real ("pos_perc", NULL, NULL,
			  0, 0, 100, 1,
			  SFI_PARAM_STANDARD);
#line 54 "bsewaveosc.proc"
}  }
static BseErrorType
#line 54 "bsewaveosc.proc"
pcm_seek_perc_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 57 "bsewaveosc.proc"
{
#line 58 "bsewaveosc.proc"
  
  BseWaveOsc *self = bse_value_get_object (in_values++);
  gfloat      pos  = sfi_value_get_real (in_values++);
  
#line 62 "bsewaveosc.proc"
  
  if (!BSE_IS_WAVE_OSC (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  bse_wave_osc_request_pcm_position (self, CLAMP (pos, 0, 100));
  
  return BSE_ERROR_NONE;
}

/* --- set-from-editable-sample --- */
static void
set_from_editable_sample_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 71 "bsewaveosc.proc"
 {
#line 73 "bsewaveosc.proc"
  *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
  *(in_pspecs++) = bse_param_spec_object ("esample", NULL, "Editable Sample",
				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
#line 77 "bsewaveosc.proc"
}  }
static BseErrorType
#line 77 "bsewaveosc.proc"
set_from_editable_sample_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 80 "bsewaveosc.proc"
{
#line 81 "bsewaveosc.proc"
  
  BseWaveOsc *self           = bse_value_get_object (in_values++);
  BseEditableSample *esample = bse_value_get_object (in_values++);

#line 85 "bsewaveosc.proc"
  
  if (!BSE_IS_WAVE_OSC (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  bse_wave_osc_set_from_esample (self, esample);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static BseExportNodeProc __enode_request_pcm_position = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "BseWaveOsc+request-pcm-position", 
    NULL,
    "/Methods/BseWaveOsc/General/Request Pcm Position",
    "Request emission of the ::notify_pcm_position signal.",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, request_pcm_position_setup, request_pcm_position_exec, 
};
static BseExportNodeProc __enode_pcm_seek_perc = {
  { (BseExportNode*) &__enode_request_pcm_position, BSE_EXPORT_NODE_PROC,
    "BseWaveOsc+pcm-seek-perc", 
    NULL,
    "/Methods/BseWaveOsc/General/Pcm Seek Perc",
    "Seek oscillator to a given pcm percentage during playback.",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, pcm_seek_perc_setup, pcm_seek_perc_exec, 
};
static BseExportNodeProc __enode_set_from_editable_sample = {
  { (BseExportNode*) &__enode_pcm_seek_perc, BSE_EXPORT_NODE_PROC,
    "BseWaveOsc+set-from-editable-sample", 
    NULL,
    "/Methods/BseWaveOsc/General/Set From Editable Sample",
    "Set wave to play from editable sample, bypassing undo and storage mechanisms.",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, set_from_editable_sample_setup, set_from_editable_sample_exec, 
};
BseExportNode* bse__builtin_init_bsewaveosc_gen_proc_c (void);
BseExportNode* bse__builtin_init_bsewaveosc_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_set_from_editable_sample;
}

/**
 ** Generated data ends here
 **/

==> beast_0.6.2.orig.tar.gz: beast-0.6.2/bse/bsewaveosc.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsewaveosc.proc"

#include <bse/bseplugin.h>
#include <bse/bsewaveosc.h>
#include <bse/bseprocedure.h>
#include <bse/bseeditablesample.h>

#line 25 "bsewaveosc.proc"


/* --- request-pcm-position --- */
static void
request_pcm_position_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 27 "bsewaveosc.proc"
 {
#line 29 "bsewaveosc.proc"
  *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
#line 31 "bsewaveosc.proc"
}  }
static BseErrorType
#line 31 "bsewaveosc.proc"
request_pcm_position_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 34 "bsewaveosc.proc"
{
#line 35 "bsewaveosc.proc"
  
  BseWaveOsc *self = bse_value_get_object (in_values++);
  
#line 38 "bsewaveosc.proc"
  
  if (!BSE_IS_WAVE_OSC (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  bse_wave_osc_request_pcm_position (self, -1);
  
  return BSE_ERROR_NONE;
}

/* --- pcm-seek-perc --- */
static void
pcm_seek_perc_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 47 "bsewaveosc.proc"
 {
#line 49 "bsewaveosc.proc"
  *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
  *(in_pspecs++) = sfi_pspec_real ("pos_perc", NULL, NULL,
			  0, 0, 100, 1,
			  SFI_PARAM_STANDARD);
#line 54 "bsewaveosc.proc"
}  }
static BseErrorType
#line 54 "bsewaveosc.proc"
pcm_seek_perc_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 57 "bsewaveosc.proc"
{
#line 58 "bsewaveosc.proc"
  
  BseWaveOsc *self = bse_value_get_object (in_values++);
  gfloat      pos  = sfi_value_get_real (in_values++);
  
#line 62 "bsewaveosc.proc"
  
  if (!BSE_IS_WAVE_OSC (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  bse_wave_osc_request_pcm_position (self, CLAMP (pos, 0, 100));
  
  return BSE_ERROR_NONE;
}

/* --- set-from-editable-sample --- */
static void
set_from_editable_sample_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 71 "bsewaveosc.proc"
 {
#line 73 "bsewaveosc.proc"
  *(in_pspecs++) = bse_param_spec_object ("wosc", NULL, "Wave Oscilator",
				 BSE_TYPE_WAVE_OSC, SFI_PARAM_STANDARD);
  *(in_pspecs++) = bse_param_spec_object ("esample", NULL, "Editable Sample",
				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
#line 77 "bsewaveosc.proc"
}  }
static BseErrorType
#line 77 "bsewaveosc.proc"
set_from_editable_sample_exec (BseProcedureClass *proc,
	const GValue      *in_values,
	GValue            *out_values)
#line 80 "bsewaveosc.proc"
{
#line 81 "bsewaveosc.proc"
  
  BseWaveOsc *self           = bse_value_get_object (in_values++);
  BseEditableSample *esample = bse_value_get_object (in_values++);

#line 85 "bsewaveosc.proc"
  
  if (!BSE_IS_WAVE_OSC (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  bse_wave_osc_set_from_esample (self, esample);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static void
__enode_request_pcm_position__fill_strings (BseExportStrings *es)
{
  es->blurb = "Request emission of the ::notify_pcm_position signal.";
  es->authors = "Tim Janik <timj@gtk.org>";
  es->license = "GNU General Public License";
}
static BseExportNodeProc __enode_request_pcm_position = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "BseWaveOsc+request-pcm-position", 
    NULL,
    "/Methods/BseWaveOsc/General/Request Pcm Position",
    NULL,
    __enode_request_pcm_position__fill_strings,
  },
  0, request_pcm_position_setup, request_pcm_position_exec, 
};
static void
__enode_pcm_seek_perc__fill_strings (BseExportStrings *es)
{
  es->blurb = "Seek oscillator to a given pcm percentage during playback.";
  es->authors = "Tim Janik <timj@gtk.org>";
  es->license = "GNU General Public License";
}
static BseExportNodeProc __enode_pcm_seek_perc = {
  { (BseExportNode*) &__enode_request_pcm_position, BSE_EXPORT_NODE_PROC,
    "BseWaveOsc+pcm-seek-perc", 
    NULL,
    "/Methods/BseWaveOsc/General/Pcm Seek Perc",
    NULL,
    __enode_pcm_seek_perc__fill_strings,
  },
  0, pcm_seek_perc_setup, pcm_seek_perc_exec, 
};
static void
__enode_set_from_editable_sample__fill_strings (BseExportStrings *es)
{
  es->blurb = "Set wave to play from editable sample, bypassing undo and storage mechanisms.";
  es->authors = "Tim Janik <timj@gtk.org>";
  es->license = "GNU General Public License";
}
static BseExportNodeProc __enode_set_from_editable_sample = {
  { (BseExportNode*) &__enode_pcm_seek_perc, BSE_EXPORT_NODE_PROC,
    "BseWaveOsc+set-from-editable-sample", 
    NULL,
    "/Methods/BseWaveOsc/General/Set From Editable Sample",
    NULL,
    __enode_set_from_editable_sample__fill_strings,
  },
  0, set_from_editable_sample_setup, set_from_editable_sample_exec, 
};
BseExportNode* bse__builtin_init_bsewaveosc_gen_proc_c (void);
BseExportNode* bse__builtin_init_bsewaveosc_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_set_from_editable_sample;
}

/**
 ** Generated data ends here
 **/
